==> hollow-cli-1.3.9.tgz: package/esm/mwBabelOptions.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 16/08/2017 13:03.
 **************************************************/
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var commonPresets, commonPlugins, _context$importSync, importSync;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            commonPresets = [['@babel/preset-env', {
              targets: {
                browsers: ['last 2 versions', 'safari >= 7', 'IE >= 11']
              },
              modules: false,
              useBuiltIns: false
            }], '@babel/preset-react'];
            commonPlugins = ['@babel/plugin-external-helpers', '@babel/plugin-transform-runtime', '@babel/plugin-transform-object-assign', '@babel/plugin-syntax-dynamic-import', '@babel/plugin-proposal-async-generator-functions', '@babel/plugin-transform-regenerator', '@babel/plugin-proposal-function-bind', '@babel/plugin-proposal-object-rest-spread', ['@babel/plugin-proposal-decorators', {
              legacy: true
            }], ['@babel/plugin-proposal-class-properties', {
              loose: true
            }], 'babel-plugin-lodash'];
            context.babelOptions = {
              cacheDirectory: true,
              babelrc: false,
              highlightCode: true,
              presets: commonPresets,
              plugins: commonPlugins
            };
            next();
            _context$importSync = context.importSync, importSync = _context$importSync === void 0 ? false : _context$importSync;

            if (importSync) {
              commonPlugins.push('babel-plugin-dynamic-import-node-sync');
            }

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}

==> hollow-cli-1.3.12.tgz: package/esm/mwBabelOptions.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";

/**************************************************
 * Created by nanyuantingfeng on 16/08/2017 13:03.
 **************************************************/
export default function (_x, _x2) {
  return _ref.apply(this, arguments);
}

function _ref() {
  _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regeneratorRuntime.mark(function _callee(context, next) {
    var commonPresets, commonPlugins, _context$optimizeDyna, optimizeDynamicImport, _context$optimizeLoda, optimizeLodash;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            commonPresets = [['@babel/preset-env', {
              targets: {
                browsers: ['last 2 versions', 'safari >= 7', 'IE >= 11']
              },
              modules: false,
              useBuiltIns: false
            }], '@babel/preset-react'];
            commonPlugins = ['@babel/plugin-external-helpers', '@babel/plugin-transform-runtime', '@babel/plugin-transform-object-assign', '@babel/plugin-syntax-dynamic-import', '@babel/plugin-proposal-async-generator-functions', '@babel/plugin-transform-regenerator', '@babel/plugin-proposal-function-bind', '@babel/plugin-proposal-object-rest-spread', ['@babel/plugin-proposal-decorators', {
              legacy: true
            }], ['@babel/plugin-proposal-class-properties', {
              loose: true
            }]];
            context.babelOptions = {
              cacheDirectory: true,
              babelrc: false,
              highlightCode: true,
              presets: commonPresets,
              plugins: commonPlugins
            };
            next();
            _context$optimizeDyna = context.optimizeDynamicImport, optimizeDynamicImport = _context$optimizeDyna === void 0 ? false : _context$optimizeDyna, _context$optimizeLoda = context.optimizeLodash, optimizeLodash = _context$optimizeLoda === void 0 ? true : _context$optimizeLoda;

            if (optimizeDynamicImport) {
              commonPlugins.push('babel-plugin-dynamic-import-node-sync');
            }

            if (optimizeLodash) {
              commonPlugins.push('babel-plugin-lodash');
            }

          case 7:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return _ref.apply(this, arguments);
}
